@@ -2,10 +2,7 @@ import django_countries
 from django.utils import timezone
 
 from basxconnect.core import models
-from basxconnect.mailer_integration.abstract.abstract_datasource import (
-    Datasource,
-    MailerPerson,
-)
+from basxconnect.mailer_integration.abstract.mailer import AbstractMailer, MailerPerson
 from basxconnect.mailer_integration.models import (
     Interest,
     Subscription,
@@ -14,12 +11,24 @@ from basxconnect.mailer_integration.models import (
 )
 
 
-def synchronize(datasource: Datasource) -> SynchronizationResult:
-    synchronize_interests(datasource)
+def synchronize(mailer: AbstractMailer) -> SynchronizationResult:
+    synchronize_interests(mailer)
 
-    mailer_persons = datasource.get_persons()
-    datasource_tag = _get_or_create_tag(datasource.tag())
+    person_count = mailer.get_person_count()
     sync_result = SynchronizationResult.objects.create()
+    sync_result.total_synchronized_persons = person_count
+    batch_size = 1000
+    for batch_number in range(((person_count - 1) // batch_size) + 1):
+        synchronize_batch(batch_size, batch_number * batch_size, mailer, sync_result)
+    sync_result.sync_completed_datetime = timezone.now()
+    sync_result.save()
+
+    return sync_result
+
+
+def synchronize_batch(count, offset, mailer, sync_result):
+    mailer_persons = mailer.get_persons(count, offset)
+    datasource_tag = _get_or_create_tag(mailer.tag())
     for mailer_person in mailer_persons:
         matching_email_addresses = list(
             models.Email.objects.filter(
@@ -42,11 +51,6 @@ def synchronize(datasource: Datasource) -> SynchronizationResult:
             # address, without creating a new person in the database
             for email in matching_email_addresses:
                 _save_subscription(email, mailer_person, sync_result)
-    sync_result.total_synchronized_persons = len(mailer_persons)
-    sync_result.sync_completed_datetime = timezone.now()
-    sync_result.save()
-
-    return sync_result
 
 
 def synchronize_interests(datasource):
